/*******************************************************************************
  Copyright(c) 2000 - 2003 Radu Corlan. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify it 
  under the terms of the GNU General Public License as published by the Free 
  Software Foundation; either version 2 of the License, or (at your option) 
  any later version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
  more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 59 
  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
  The full GNU General Public License is included in this distribution in the
  file called LICENSE.
  
  Contact Information: radu@corlan.net
*******************************************************************************/

// cpxcon_regs.h: register defines for cpxcon fpga (camera control regs)
// $Revision: 1.1 $
// $Date: 2003/05/29 01:31:03 $

#ifndef _CPXCON_REGS_H

#define _CPXCON_REGS_H

// max value to output on cooling power register
#define MAXCOOL 127

/* defines for EPP port acess */
#define xiadr(x) outb((x),0x37b)	
#define xiwr(x) outb((x),0x37c)
#define xird() inb(0x37c)

// control registers for head #1

//instruction register for head #1
//the instruction register (r/w) is cleared when an instruction is completed
#define INSTREG1 	0 

// valid istructions:
//  0: NOP
#define CPXNOP		0

//  1: RDTEMP Read Temperature
//      generates two result words, of which the first is invalid. The second
//		holds the cooling plate temperature.
#define RDTEMP 		1

//  2: VSFMS  Vertical shift & flush main sensor.
//            Discards (iparam + 1) lines from the top of the sensor.
//            For each vertical shift, binreg[3:0] hosrisontal shifts
//		and resets are performed. 
#define VSFMS 		2

//  4: VSBMS  Vertical shift and bin main sensor.
//            bins the top (iparam + 1) lines into the horisontal
//            register for readout.
#define VSBMS 		4

//  8: HSFMS  Horisontal shift and flush main sensor.
//            Flushes (iparam + 1) pixels from the start of the horisontal
//            register
#define HSFMS 		8

// 16: READMS Read main sensor (iparam + 1) * (binreg[3:0] + 1) columns, 
//            generating (iparam + 1) * 2 * (binreg[7:4] + 1) result words .
#define READMS 		16

// 32: READGS Read guide sensor; does binreg [3:0] + 1 vertical shifts
// 		and reads BINREG1[7:4] & IPARAM1 + 1 pixels, with binning.
#define READGS		32

// 64 TRNSFGS Transfer guide sensor; vertical shifts BINREG1[7:4] & IPARAM1 + 1
// lines
#define TRNSFGS		64

// 128: SKIPGS Skip pixels on guide sensor. Discard BINREG1[7:4] & IPARAM1 + 1
// pixels from the start of the horisontal register
#define SKIPGS		128

// end of instruction list

// head 1 parameter register (w/o); holds instruction parameter (typically the
// length of an operation
#define IPARAM1		1

// head 1 binning register (w/o)
// bits [3:0] contain the amount of pixels to be binned
// bits [7:4] are used to extend IPARAM1 for the repeated ops.
#define BINREG1		2

// Byte pointer reset register 
// A write to the BPTRES1 register (decoded elswhere) resets the 
// byte pointer to the high byte of the results register
#define BPTRES1 	3

// Exposure time register low (r/w)
// exposure time (in 20ms units) low byte 
// a write to EXPREG1L will start or extend an exposure with 
// EXPREG1H & EXPREG1L * 20ms; a value of FFFF means indefinite duration
// a read returns the remaining time
#define EXPREG1L	4

// Exposure time register high (r/w)
// exposure time (in 20ms units) high byte 
// a read returns the remaining time
#define EXPREG1H	5

// Misc controls head 1 (r/w)
// Bit field register
#define MCTRL1		6

// Bit assignments:
#define MC_SHTREN	1	// bit 0: enable shutter
#define MC_SOUTEN	2	// bit 1: enable serial out; must be kept at '0' for 
                                // more than 1us to reset the receiver
#define MC_AMPEN	4	// enable main sensor output stage bias
#define MC_GAIN1	8	// enable X2 amplification
#define MC_ODBDR	16	// enable guide sensor clear
#define MC_SNSSEL	32	// select sensor for readout (1 = main)
#define MC_INPSEL	64	// select ccd/temperature readout (0 = temperature)
#define MC_ADCRES	128	// reset adc when '1'
// End of bit assignments

// Cooling power register head #1 (255=max)
#define CPWR1		7

// hard cds enable register
// bit 0 enables the hard cds mode
// bits [7:4] program the number of times the adc conversions are averaged

#define HARDCDS1	8

// Data register (r/o); Used to get data from the top of the fifo, high byte first
#define DATAREG1	7

// Fifo size register; returns the number of 16-bit words in fifo
#define FIFOSIZE1	2

#endif
